@@ -25,7 +25,7 @@ angles.
 
 =head1 AUTHOR
 
-Chris Phillips  phillips@jive.nl
+Chris Phillips  Chris.Phillips@csiro.au
 
 =head1 FUNCTIONS
 
